import {login, getInfo} from '@/api/user'
import {getToken, setToken, removeToken} from '@/utils/auth'
import {encoded, decoded} from '@/utils/cryptor'
import router, {resetRouter} from '@/router'

const state = {
  token: getToken(),
  username: '',
  roles: [],
}

const mutations = {
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  SET_USERNAME: (state, username) => {
    state.username = username
  },
  SET_ROLES: (state, roles) => {
    state.roles = roles
  },
}

const actions = {
  // user login
  login({commit, dispatch}, userInfo) {
    const {username, password, platform} = userInfo
    return new Promise((resolve, reject) => {
      login({username: username.trim(), password: password, platform: platform})
        .then(async response => {
          const token = encoded(username)
          commit('SET_TOKEN', token)
          setToken(token)
          resolve()
        })
        .catch(error => {
          console.log(error)
          reject(error)
        })
    })
  },

  // get user info
  getInfo({commit, state}) {
    return new Promise((resolve, reject) => {
      const username = decoded(state.token)
      if (!username) {
        resolve({})
      }
      getInfo({search: username, field: 'uid'})
        .then(response => {
          const {data} = response
          const userInfo = data[0]
          const roles = [userInfo.employeeType]
          if (!userInfo) {
            reject('Verification failed, please Login again.')
          }

          commit('SET_USERNAME', userInfo.uid)
          commit('SET_ROLES', roles)

          userInfo.roles = roles

          resolve(userInfo)
        })
        .catch(error => {
          reject(error)
        })
    })
  },

  // user logout
  logout({commit, state}) {
    return new Promise((resolve, reject) => {
      commit('SET_TOKEN', '')
      commit('SET_USERNAME', '')
      commit('SET_ROLES', [])
      removeToken()
      resetRouter()
      resolve()
    })
  },

  // remove token
  resetToken({commit}) {
    return new Promise(resolve => {
      commit('SET_TOKEN', '')
      removeToken()
      resolve()
    })
  },

  // dynamically modify permissions
  changeRoles({commit, dispatch}, role) {
    return new Promise(async resolve => {
      const token = role + '-token'

      commit('SET_TOKEN', token)
      setToken(token)

      const {roles} = await dispatch('getInfo')

      resetRouter()

      // generate accessible routes map based on roles
      const accessRoutes = await dispatch('permission/generateRoutes', roles, {
        root: true,
      })

      // dynamically add accessible routes
      router.addRoutes(accessRoutes)

      resolve()
    })
  },
}

export default {
  namespaced: true,
  state,
  mutations,
  actions,
}
