import axios from 'axios'
import {MessageBox, Message} from 'element-ui'
import store from '@/store'
import getToken from '@/utils/ldap-token'

// create an axios instance
const service = axios.create({
  baseURL: process.env.VUE_APP_LDAP_API, // url = base url + request url
  // withCredentials: true, // send cookies when cross-domain requests
  timeout: 5000, // request timeout
})

// request interceptor
service.interceptors.request.use(
  async config => {
    // do something before request is sent
    const tokenData = await getToken()
    const token = tokenData.data.token
    config.headers['authorization'] = 'Bearer ' + token

    return config
  },
  error => {
    // do something with request error
    console.log(error) // for debug
    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
   */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  response => {
    const {data, status} = response

    if (status !== 200) {
      Message({
        message: data.error || 'error',
        type: 'error',
        duration: 5 * 1000
      })
      return Promise.reject(data.errmsg || 'error')
    } else {
      return response
    }
  },
  error => {
    console.log(error.response) // for debug
    const data = error.response.data
    const errmsg = data.error
    console.log(errmsg)
    Message({
      message: errmsg || error.message,
      type: 'error',
      duration: 5 * 1000,
    })
    return Promise.reject(error)
  }
)

export default service
